@@ -11,6 +11,10 @@
 #include "ui_accrealtimedialog.h"
 #include <math.h>
 
+/**
+  * Default constructor for AccRealTimeDialog class.
+  *
+  */
 AccRealTimeDialog::AccRealTimeDialog(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::AccRealTimeDialog)
@@ -19,6 +23,7 @@ AccRealTimeDialog::AccRealTimeDialog(QWidget *parent) :
 
     accelerometer = new Accelerometer();
     movingAverageZ = new MovingAverage(10);
+    movingAverageY = new MovingAverage(10);
     calculate = new Calculate();
     accelerationStartThreshold = 0.1;
 
@@ -31,6 +36,10 @@ AccRealTimeDialog::AccRealTimeDialog(QWidget *parent) :
     resultDialog = NULL;
 }
 
+/**
+  * Default destructor for AccRealTimeDialog class.
+  * Deletes all dynamic objects and sets them to NULL.
+  */
 AccRealTimeDialog::~AccRealTimeDialog()
 {
     delete ui;
@@ -38,10 +47,14 @@ AccRealTimeDialog::~AccRealTimeDialog()
     delete accelerometerTimer;
     delete calculate;
     delete movingAverageZ;
+    delete movingAverageY;
     if(resultDialog)
         delete resultDialog;
 }
 
+/**
+  *
+  */
 void AccRealTimeDialog::changeEvent(QEvent *e)
 {
     QDialog::changeEvent(e);
@@ -53,8 +66,9 @@ void AccRealTimeDialog::changeEvent(QEvent *e)
         break;
     }
 }
+
 /**
-  *This function is called to read (and process) data from the accelerometer
+  * This function is called to read (and process) data from the accelerometer
   */
 void AccRealTimeDialog::readAccelerometerData()
 {
@@ -64,25 +78,50 @@ void AccRealTimeDialog::readAccelerometerData()
 
     accelerometer->getAcceleration(x, y, z);
 
-    //  keep the following line as close to the SetKinematicsProperties method as possible
+    // keep the following line as close to the SetKinematicsProperties method as possible
     currentTime = elapsedTime.elapsed();
 
-    //accelerometer->smoothData(x, y, z);
-
-    //Calculate average
+    // Calculate average for Z
     movingAverageZ->Enqueue(z);
     z = movingAverageZ->Average();
+    // Calculate average for Y
+    movingAverageY->Enqueue(y);
+    y = movingAverageY->Average();
 
     // Apply calibration
     x -= accelerometer->getCalibrationX();
     y -= accelerometer->getCalibrationY();
     z -= accelerometer->getCalibrationZ();
 
-//    QString str = QString("acc x: " + QString::number(x) + "\n" +
-//                          "acc y: " + QString::number(y) + "\n" +
-//                          "acc z: " + QString::number(z) + "\n");
+    qreal calY = accelerometer->getCalibrationY();
+    qreal calZ = accelerometer->getCalibrationZ();
 
-    currentAcceleration = z;//sqrt(x*x + y*y + z*z);
+    if(calY < 0)
+        calY = -calY;
+    if(calZ < 0)
+        calZ = -calZ;
+
+    // Take acceleration from more affecting axel
+    if(calZ < calY)
+    {
+        z = z*(1+calZ/2);
+        currentAcceleration = z;
+    }
+    else
+    {
+        y = y*(1+calY/2);
+        currentAcceleration = -y;
+    }
+
+    //screen up: y = 0, z = -1
+    //screen front: y = -1, z = 0
+
+    //QString str = QString("acc x: " + QString::number(x) + "\n" +
+    //                      "acc y: " + QString::number(y) + "\n" +
+    //                      "acc z: " + QString::number(z) + "\n");
+
+    //currentAcceleration = z;//sqrt(x*x + y*y + z*z);
+    //qDebug("y: %f, calibZ: %f, calibY: %f\n",y,accelerometer->getCalibrationZ(),accelerometer->getCalibrationY());
     changeInAcceleration = currentAcceleration;
 
     if (((fabs(changeInAcceleration) <= accelerationStartThreshold)
@@ -156,6 +195,7 @@ void AccRealTimeDialog::readAccelerometerData()
             {
                 resultDialog->setValue(i*10,tempMap[i*10]);
             }
+            calculate->reset();
             resultDialog->show();
             this->hide();
         }
@@ -180,11 +220,17 @@ void AccRealTimeDialog::resetAccelerometerMeasurements()
     stopMeasureSpeed = 0;
 }
 
+/**
+  *
+  */
 void AccRealTimeDialog::Calibrate()
 {
     accelerometer->calibrate();
 }
 
+/**
+  * This slot function called when ever abort button clicked.
+  */
 void AccRealTimeDialog::on_buttonAbort_clicked()
 {
     accelerometerTimer->stop();
@@ -192,6 +238,9 @@ void AccRealTimeDialog::on_buttonAbort_clicked()
     this->close();
 }
 
+/**
+  *
+  */
 void AccRealTimeDialog::startAccelerationMeasure()
 {
     double temp = stopMeasureSpeed;
@@ -200,6 +249,10 @@ void AccRealTimeDialog::startAccelerationMeasure()
     accelerometerTimer->start(40);
 }
 
+/**
+  *
+  * @param double speed
+  */
 void AccRealTimeDialog::SetStopMeasureSpeed(double speed)
 {
     stopMeasureSpeed = speed;
@@ -208,7 +261,8 @@ void AccRealTimeDialog::SetStopMeasureSpeed(double speed)
 /**
   *This slot function emit accelerationstart sendresult.
   *
-  **/
+  * @param double result
+  */
 void AccRealTimeDialog::sendResult(double result)
 {
     emit sendresult(result);
