@@ -1,7 +1,7 @@
 /*
  * Help dialog
  *
- * @author     Janne Änäkkälä <janne.anakkala@fudeco.com>
+ * @author     Janne Änäkkälä   <janne.anakkala@fudeco.com>
  * @author     Toni Jussila 	<toni.jussila@fudeco.com>
  * @copyright  (c) 2010 Speed Freak team
  * @license    http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -14,8 +14,9 @@
 #include <helpresultsdialog.h>
 #include <helpaccelerationdialog.h>
 #include <helproutingdialog.h>
-#include "creditsdialog.h"
 #include <helpsettingsdialog.h>
+#include "creditsdialog.h"
+#include <helpusersdialog.h>
 
 namespace Ui {
     class HelpDialog;
@@ -32,6 +33,7 @@ public:
    HelpRoutingDialog *helpRoutingDialog;
    CreditsDialog *creditsDialog;
    HelpSettingsDialog *helpSettingsDialog;
+   HelpUsersDialog *helpUsersDialog;
 
 protected:
     void changeEvent(QEvent *e);
@@ -41,6 +43,7 @@ private:
 
 
 private slots:
+    void on_pushButtonHelpUsers_clicked();
     void on_pushButtonHelpSettings_clicked();
     void on_pushButtonCredits_clicked();
     void on_pushButtonHelpRoute_clicked();
