@@ -3,6 +3,7 @@
  *
  * @author      Rikhard Kuutti  <rikhard.kuutti@fudeco.com>
  * @author      Toni Jussila 	<toni.jussila@fudeco.com>
+ * @author      Janne Änäkkälä  <janne.anakkala@fudeco.com>
  * @copyright   (c) 2010 Speed Freak team
  * @license     http://opensource.org/licenses/gpl-license.php GNU Public License
  */
@@ -27,6 +28,7 @@
 #include "resultdialog.h"
 #include "helpdialog.h"
 #include "custombutton.h"
+#include "usersdialog.h"
 
 
 namespace Ui {
@@ -48,6 +50,7 @@ public:
     TopResultDialog *topResultDialog;
     HttpClient *httpClient;
     HelpDialog *helpDialog;
+    UsersDialog *usersDialog;
 
 protected:
     void changeEvent(QEvent *e);
@@ -62,8 +65,9 @@ private:
     CustomButton* customButtonSettings;
     CustomButton* customButtonWWW;
     CustomButton* customButtonHelp;
+    CustomButton* customButtonUsers;
 
-private slots:
+private slots:    
     void clientRequestCategoryList();
     void clientRequestTopList(int index);
     void clientSendRoute(QString,QString,int);
@@ -81,6 +85,9 @@ private slots:
     void OpenWWWPage();
     void OpenHelpDialog();
     void OpenSettingsDialog();
+    void requestGetUserInfo(QString);
+    void requestGetUsers();
+    void openUsersDialog();
 };
 
 #endif // MAINWINDOW_H
